# Code of Conduct

## Our Pledge

In the interest of fostering an open and welcoming environment, contributors and maintainers pledge to make participation in this project a harassment-free experience for everyone.

## Our Standards

Examples of behavior that contributes to a positive environment include:

- Being respectful and inclusive.
- Giving and accepting constructive feedback.
- Focusing on what is best for the community and users.

Examples of unacceptable behavior include:

- Harassment, insulting, or derogatory comments.
- Public or private intimidation.
- Any conduct that would be inappropriate in a professional setting.

## Enforcement Responsibilities

Project maintainers are responsible for clarifying and enforcing acceptable behavior and may remove, edit, or reject comments, commits, code, and other contributions that are not aligned with this Code of Conduct.

## Scope

This Code of Conduct applies within project spaces and in public spaces when an individual is representing the project.

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported by opening a private security advisory or contacting maintainers through repository discussions.

Maintainers will review and investigate all complaints and will respond in a way that they deem appropriate to the circumstances.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.1:
https://www.contributor-covenant.org/version/2/1/code_of_conduct/
